<?php

namespace Drupal\reaction\Plugin\Field\FieldType;

use Drupal\Component\Utility\Random;
use Drupal\Core\Field\FieldDefinitionInterface;
use Drupal\Core\Field\FieldItemBase;
use Drupal\Core\Field\FieldStorageDefinitionInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\TypedData\DataDefinition;
use Drupal\Core\TypedData\MapDataDefinition;
use Drupal\Core\Url;
use Drupal\link\LinkItemInterface;

/**
 * Plugin implementation of the 'link' field type.
 *
 * @FieldType(
 *   id = "reaction",
 *   label = @Translation("Reaction"),
 *   description = @Translation("Stores a URL string, optional varchar link text, and optional blob of attributes to assemble a link."),
 *   default_widget = "reaction_default",
 *   default_formatter = "reaction",
 *   constraints = {"LinkType" = {}, "LinkAccess" = {}, "LinkExternalProtocols" = {}, "LinkNotExistingInternal" = {}}
 * )
 */
class ReactionItem extends FieldItemBase {

  /**
   * {@inheritdoc}
   */
  public static function defaultFieldSettings() {
    return array(
      'reaction_style' => ['smiling-face-with-sunglasses', 'white-smiling-face']
        ) + parent::defaultFieldSettings();
  }

  /**
   * {@inheritdoc}
   */
  public static function schema(FieldStorageDefinitionInterface $field_definition) {
    return array(
      'columns' => array(
        'value' => array(
          'type' => 'text',
          'size' => 'tiny',
          'not null' => FALSE,
        ),
      ),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function isEmpty() {
    $value = $this->get('value')->getValue();
    return $value === NULL || $value === '';
  }

  /**
   * {@inheritdoc}
   */
  public static function propertyDefinitions(FieldStorageDefinitionInterface $field_definition) {
    $properties['value'] = DataDefinition::create('string')
        ->setLabel(t('Hex value'))
        ->setRequired(TRUE);

    return $properties;
  }

  /**
   * {@inheritdoc}
   */
  public function fieldSettingsForm(array $form, FormStateInterface $form_state) {
    global $base_url;
    $module_path = drupal_get_path('module', 'reaction');
    $element = array();
    $path = drupal_get_path('module', 'reaction');
    if ($handle = opendir($path . '/vendor/krknth/reaction/google')) {
      while (false !== ($entry = readdir($handle))) {
        if ($entry != "." && $entry != "..") {
          $reaction_name = substr($entry, 0, strpos($entry, "."));
          $reaction_style_option[$reaction_name] = '<img src = ' . $base_url . '/' . $module_path . '/vendor/krknth/reaction/google/' . $reaction_name . '.png';
        }
      }
      closedir($handle);
    }
    $element['reaction_style'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Select your emoji'),
      '#options' => $reaction_style_option,
      '#default_value' => $this->getSetting('reaction_style'),
    );
    return $element;
  }

}
